summaryrefslogtreecommitdiffstats
path: root/app/config.go
diff options
context:
space:
mode:
Diffstat (limited to 'app/config.go')
-rw-r--r--app/config.go8
1 files changed, 5 insertions, 3 deletions
diff --git a/app/config.go b/app/config.go
index ccd7236a0..761fe3ec9 100644
--- a/app/config.go
+++ b/app/config.go
@@ -273,15 +273,17 @@ func (a *App) GetSiteURL() string {
return a.siteURL
}
-// ClientConfigWithNoAccounts gets the configuration in a format suitable for sending to the client.
-func (a *App) ClientConfigWithNoAccounts() map[string]string {
+// ClientConfigWithComputed gets the configuration in a format suitable for sending to the client.
+func (a *App) ClientConfigWithComputed() map[string]string {
respCfg := map[string]string{}
for k, v := range a.ClientConfig() {
respCfg[k] = v
}
- // NoAccounts is not actually part of the configuration, but is expected by the client.
+ // These properties are not configurable, but nevertheless represent configuration expected
+ // by the client.
respCfg["NoAccounts"] = strconv.FormatBool(a.IsFirstUserAccount())
+ respCfg["MaxPostSize"] = strconv.Itoa(a.MaxPostSize())
return respCfg
}